@@ -1,5 +1,5 @@
 from jarvis.io.vasp.outputs import Vasprun, Outcar
-from jarvis.analysis.phonon.ir import ir_intensity
+from jarvis.analysis.phonon.ir import ir_intensity, ir_intensity_phonopy
 
 import os
 
@@ -8,16 +8,23 @@ out = Outcar(
         os.path.dirname(__file__), "..", "..", "io", "vasp", "OUTCAR.JVASP-39"
     )
 )
-vrun = Vasprun(
-    os.path.join(
-        os.path.dirname(__file__),
-        "..",
-        "..",
-        "io",
-        "vasp",
-        "vasprun.xml.JVASP-39",
-    )
+vrun_file = os.path.join(
+    os.path.dirname(__file__),
+    "..",
+    "..",
+    "io",
+    "vasp",
+    "vasprun.xml.JVASP-39",
 )
+dirc = os.path.join(
+    os.path.dirname(__file__),
+    "..",
+    "..",
+    "io",
+    "vasp",
+)
+
+vrun = Vasprun(vrun_file)
 
 
 def test_ir():
@@ -33,8 +40,9 @@ def test_ir():
         born_charges=born_charges,
     )
     print(max(y))
-    assert max(y) == 0.3511482090386446
+    assert round(max(y), 2) == round(0.3511482090386446, 2)
     pdos = vrun.partial_dos_spdf
+    x, y = ir_intensity_phonopy(vasprun=vrun_file, run_dir=dirc)
 
 
 test_ir()
